@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moo::Role;
 
@@ -17,15 +17,6 @@ use POSIX;
 use Scalar::Util qw(looks_like_number);
 use Try::Tiny;
 
-has 'interpolate' => (
-    is       => 'ro',
-    isa      => sub {
-        die "Must be Interpolate class"
-        unless ref $_[0] eq 'Math::Function::Interpolator';
-    },
-    required => 1
-);
-
 =head1 NAME
 
 Math::Function::Interpolator::Quadratic
@@ -45,6 +36,24 @@ Math::Function::Interpolator::Quadratic
 Math::Function::Interpolator::Quadratic helps you to do the interpolation calculation with quadratic method.
 It solves the interpolated_y given point_x and a minimum of 5 data points. 
 
+=head1 FIELDS
+
+=head2 interpolate (REQUIRED)
+
+Interpolations class object
+
+=cut
+
+has 'interpolate' => (
+    is       => 'ro',
+    isa      => sub {
+        die "Must be Interpolate class"
+        unless ref $_[0] eq 'Math::Function::Interpolator';
+    },
+    required => 1
+);
+
+
 =head1 METHODS
 
 =head2 do_calculation
